Imports System
Imports System.Web.UI
Imports System.Web.UI.WebControls

Namespace Templates

	' Base template for site
	Public Class PageTemplateVB : Inherits Page

		' HTML title
    Private _title As System.Web.UI.LiteralControl = New System.Web.UI.LiteralControl
		' Stylesheet file location
    Private _styleSheet As System.Web.UI.LiteralControl = New System.Web.UI.LiteralControl
		' Common site web user control.
		Protected TopBar As TemplateAppVB.Components.TopBar
		' Temporary control collection to hold parsed controls.
		Protected ControlBin As ControlCollection
		' Placeholder for the HTML HEAD section.
		Protected Head As PlaceHolder = New PlaceHolder()
		' Placeholder for the body/content section of the form all controls on inheritors will be added to Me.
		Protected Body As PlaceHolder = New PlaceHolder()
		' Standard form for the page
		Protected MainForm As System.Web.UI.HtmlControls.HtmlForm = New System.Web.UI.HtmlControls.HtmlForm()

		' Gets or sets HTML title for the page
		Protected Property Title() As String
			Get
				Return Me._title.Text
			End Get

			Set(ByVal value As String)
        Me._title.Text = "My Site Title Prefix: " & value
        ViewState("PageTitle") = Me._title.Text
			End Set
		End Property

		' Gets or sets stylesheet location
		Protected Property StyleSheet() As String
			Get
				Return Me._styleSheet.Text
			End Get

			Set(ByVal value As String)
        Me._styleSheet.Text = value
        ViewState("StyleSheet") = Me._styleSheet.Text
			End Set
		End Property

		' Receives the objects parsed from the ASPX page and adds them to a Private control collection
		' <param name="obj">Parsed object.</param>
		Protected Overrides Sub AddParsedSubObject(ByVal obj As Object)
			' If this is the first time here, instantiate our control collection
			If IsNothing(ControlBin) Then
				ControlBin = New ControlCollection(Me)
			End If
			' add the control to our holding bin collection
			Me.ControlBin.Add(CType(obj, System.Web.UI.Control))
		End Sub

		' Page init calls Private method LoadControls, which adds IDs to template controls, loads the TopBar control, and defines the template page layout
		' <param name="e">Page init event arguments</param>
		Protected Overrides Sub OnInit(ByVal e As EventArgs)
			Me.LoadControls()
			MyBase.OnInit(e)
		End Sub


		' Adds IDs to template controls, loads the TopBar control, and defines the template page layout
		Private Sub LoadControls()

			' Load TopBar control this is just an example of how to use a user control w/ the template actual control not included in sample
			Me.TopBar = CType(Me.LoadControl(Me.Request.ApplicationPath & "/Components/TopBar.ascx"), TemplateAppVB.Components.TopBar)
			' Add IDs to template controls
			Me.Head.ID = "HEAD"
			Me.TopBar.ID = "TopBar"
			Me.MainForm.ID = "MainForm"
            Me.Body.ID = "BODY"
            ' ''''''
			' Begin page layout
			' ''''''
			' Add standard HTML, title, & stylesheet tags
			AddStaticText("<!DOCTYPE HTML PUBLIC ""-//W3C//DTD XHTML 1.0 Transitional//EN"" >" & _
		 "<html>" & vbCrLf & _
		 "<head>" & vbCrLf & _
		 "<title>")
			Me.Controls.Add(Me._title)
			AddStaticText("</title>" & vbCrLf & _
			 "<link type=""text/css"" rel=""stylesheet"" href=""")
			Me.Controls.Add(Me._styleSheet)
			AddStaticText(""">" & vbCrLf)
			' Add Head to the HEAD section
			Me.Controls.Add(Me.Head)
			' Close Head section open body section
			AddStaticText( _
			 "</head>" & vbCrLf & _
			 "<body>" & vbCrLf)
			' Add the TopBar control to top of form
			Me.MainForm.Controls.Add(Me.TopBar)
			' Add a central div for body to form
			Me.MainForm.Controls.Add(New LiteralControl("<div id=""bodyDiv"">"))
			' Load all of the controls from the child page into the Body PlaceHolder on the template
			Dim i As Integer
			For i = 0 To ControlBin.Count - 1
				Me.Body.Controls.Add(ControlBin(i))
			Next
			' Add body placeholder to form
			Me.MainForm.Controls.Add(Me.Body)
			' Add close body div and add standard footer to form
			Me.MainForm.Controls.Add(New LiteralControl( _
			 "</div>" & _
			 "<div class=""templateFooter""><nobr>Copyright &copy 2002 My Company</nobr></div>"))
			' Add form to page
			Me.Controls.Add(Me.MainForm)
			' close standard body & HTML tags
			AddStaticText( _
			 "</body>" & vbCrLf & _
			 "</html>" & vbCrLf)
		End Sub


		' Helper method to add literal controls to page
		Private Sub AddStaticText(ByVal output As String)
			Me.Controls.Add(New LiteralControl(output))
		End Sub

    ' Loads view state
    Protected Overrides Sub LoadViewState(ByVal savedState As Object)
      MyBase.LoadViewState(savedState)
      ' Initialize Page Title & Stylesheet
      Me._title.Text = Convert.ToString(ViewState("PageTitle"))
      If Me._title.Text = String.Empty Then _
           Me._title.Text = "My Default Title Here"
      Me._styleSheet.Text = Convert.ToString(ViewState("StyleSheet"))
      If Me._styleSheet.Text = String.Empty Then _
             Me._styleSheet.Text = "myDefaultStyleSheet.css"
    End Sub

  End Class
End Namespace
